Useful links
============

  #. `<http://ec.europa.eu/ipg/basics/legal/cookies/index_en.htm/>`_
  #. `<http://en.wikipedia.org/wiki/Directive_on_Privacy_and_Electronic_Communications/>`_
  #. `<http://www.python.org/>`_
  #. `<https://www.djangoproject.com/>`_
  #. `<https://docs.djangoproject.com/en/dev/intro/tutorial01/>`_
